export( "checkNames" )
export( "coefTable" )
export( "colMedians" )
export( "rowMedians" )
export( "compPlot" )
export( "ddnorm" )
export( "histDens" )
export( "insertCol" )
export( "insertRow" )
export( "isSemidefinite" )
export( "margEff" )
export( "nObs" )
export( "nParam" )
export( "quasiconcavity" )
export( "quasiconvexity" )
export( "rSquared" )
export( "semidefiniteness" )
export( "stdEr" )
export( "sumKeepAttr" )
export( "summarizeDF" )
export( "symMatrix" )
export( "triang" )
export( "vecli" )
export( "vecli2m" )
export( "veclipos" )

S3method( "isSemidefinite", "default" )
S3method( "isSemidefinite", "list" )
S3method( "isSemidefinite", "matrix" )
S3method( "margEff", "default" )
S3method( "nObs", "default" )
S3method( "nObs", "lm" )
S3method( "nParam", "default" )
S3method( "nParam", "lm" )
S3method( "stdEr", "default" )
S3method( "stdEr", "lm" )

importFrom( "digest", "digest" )
importFrom( "graphics", "abline" )
importFrom( "graphics", "hist" )
importFrom( "graphics", "lines" )
importFrom( "graphics", "plot.default" )
importFrom( "stats", "coef" )
importFrom( "stats", "coefficients" )
importFrom( "stats", "density" )
importFrom( "stats", "dnorm" )
importFrom( "stats", "median" )
importFrom( "stats", "pt" )
importFrom( "stats", "vcov" )
importFrom( "stats", "sd" )
importFrom( "utils", "combn" )
